@@ -1,7 +1,8 @@
-mv bin/tar-incoming bin/tar
-( cd bin ; rm -rf tar-1.13.25 )
-( cd bin ; ln -sf tar tar-1.13.25 )
+( cd bin ; rm -rf tar-1.14 )
+( cd bin ; ln -sf tar tar-1.14 )
 ( cd etc ; rm -rf rmt )
 ( cd etc ; ln -sf /usr/libexec/rmt rmt )
+( cd usr/bin ; rm -rf tar )
+( cd usr/bin ; ln -sf /bin/tar tar )
 ( cd sbin ; rm -rf rmt )
 ( cd sbin ; ln -sf /usr/libexec/rmt rmt )
